@@ -1,13 +1,14 @@
 #!/usr/bin/env python
 
-gameMusic = 0
-gameSound = 1
+# Configuration
+gameMusic = False
+gameSound = True
 player_speed = 8
 enemy_speed = 6
 players = 1
+
+# Game state
 lives = 2
-mariomode = 0
-paper = 0
 boss = 0
 greenScore = 0
 purpleScore = 0
@@ -19,3 +20,5 @@ greenHitsTotal = 0
 purpleHitsTotal = 0
 deathCount = 3
 currentLvl = 0
+areMonstersEvil = False
+levelselect = 0
