@@ -3,10 +3,10 @@ import os
 __pretty_app_name__ = "Omnom"
 __app_name__ = "omnom"
 __version__ = "0.3.0"
-__build__ = 1
+__build__ = 2
 __app_magic__ = 0xdeadbeef
 _data_path_ = os.path.join(os.path.expanduser("~"), ".%s" % __app_name__)
 _user_settings_ = "%s/settings.ini" % _data_path_
 _user_logpath_ = "%s/%s.log" % (_data_path_, __app_name__)
 IS_MAEMO = True
-IS_PYGAME_PROFILING = True
+IS_PYGAME_PROFILING = False
